@@ -17,7 +17,7 @@ BEGIN {
 
 use Exporter ();
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-$VERSION   = '2.10_001';
+$VERSION   = '2.10_002';
 $VERSION   = eval $VERSION;
 @ISA       = qw(Exporter);
 @EXPORT    = qw(mkpath rmtree);
@@ -577,7 +577,7 @@ as username is assumed. An error will be issued if the username cannot be
 mapped to a uid, or the uid does not exist, or the process lacks the
 privileges to change ownership.
 
-Ownwership of directories that already exist will not be changed.
+Ownership of directories that already exist will not be changed.
 
 C<user> and C<uid> are aliases of C<owner>.
 
@@ -589,7 +589,7 @@ as group name is assumed. An error will be issued if the group name cannot be
 mapped to a gid, or the gid does not exist, or the process lacks the
 privileges to change group ownership.
 
-Group ownwership of directories that already exist will not be changed.
+Group ownership of directories that already exist will not be changed.
 
     make_path '/var/tmp/webcache', {owner=>'nobody', group=>'nogroup'};
 
@@ -736,7 +736,7 @@ An example usage looks like:
 
 Note that if no errors are encountered, C<$err> will reference an
 empty array.  This means that C<$err> will always end up TRUE; so you
-need to test C<@$err> to determine if errors occured.
+need to test C<@$err> to determine if errors occurred.
 
 =head2 NOTES
 
@@ -982,7 +982,7 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=File-Path>
 
 You can also send pull requests to the Github repository:
 
-L<https://github.com/dland/File-Path>
+L<https://github.com/rpcme/File-Path>
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -996,8 +996,11 @@ Gisle Aas made a number of improvements to the documentation for
 
 =head1 AUTHORS
 
-Tim Bunce and Charles Bailey. Currently maintained by David Landgren
-<F<david@landgren.net>>.
+Prior authors and maintainers: Tim Bunce, Charles Bailey, and
+David Landgren <F<david@landgren.net>>.
+
+Current maintainers are Richard Elberger <F<riche@cpan.org>> and
+James (Jim) Keenan <F<jkeenan@cpan.org>>.
 
 =head1 CONTRIBUTORS
 
@@ -1019,8 +1022,8 @@ Contributors to File::Path, in alphabetical order.
 
 =head1 COPYRIGHT
 
-This module is copyright (C) Charles Bailey, Tim Bunce and
-David Landgren 1995-2013. All rights reserved.
+This module is copyright (C) Charles Bailey, Tim Bunce, David Landgren,
+and Richard Elberger 1995-2015. All rights reserved.
 
 =head1 LICENSE
 
